==> libxpertmass_1.3.0.orig.tar.gz: libxpertmass-1.3.0/source/XpertMassGui/includes/MsXpS/libXpertMassGui/ScriptingObjectTreeWidgetItem.hpp <==
/* BEGIN software license
 *
 * msXpertSuite - mass spectrometry software suite
 * -----------------------------------------------
 * Copyright(C) 2009,...,2018 Filippo Rusconi
 *
 * http://www.msxpertsuite.org
 *
 * This file is part of the msXpertSuite project.
 *
 * The msXpertSuite project is the successor of the massXpert project. This
 * project now includes various independent modules:
 *
 * - massXpert, model polymer chemistries and simulate mass spectrometric data;
 * - mineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 * END software license
 */


#pragma once


/////////////////////// Qt includes
#include <QTreeWidgetItem>


///////////////////////////// Local includes
#include "MsXpS/libXpertMassCore/globals.hpp"

#include "MsXpS/libXpertMassGui/ScriptingWnd.hpp"


namespace MsXpS
{
namespace libXpertMassGui
{

class ScriptingObjectTreeWidgetItem: public QObject, QTreeWidgetItem
{

  Q_OBJECT
  friend class ScriptingWnd;

  public:
  ScriptingObjectTreeWidgetItem(QTreeWidget *parent, int type);
  ScriptingObjectTreeWidgetItem(QTreeWidgetItem *parent, int type);
  ~ScriptingObjectTreeWidgetItem();

  void setQObject(QObject *object);
  void setComment(const QString &comment);
  void setHelp(const QString &help);
  void setColor(const QColor &color);
  void setScriptEntityType(ScriptEntityType type);

  void setProperties(QObject *object        = Q_NULLPTR,
                     const QString &comment = QString(),
                     const QString &help    = QString(),
                     const QColor &color    = Qt::black,
                     ScriptEntityType entityType =
                       ScriptEntityType::UndefinedEntity);

  public slots:

  void setText(int column, const QString &text);

  private:
  QObject *mp_qobject = Q_NULLPTR;
  QString m_comment;
  QString m_help;
  QColor m_color;
  ScriptEntityType m_entityType;
};

} // namespace libXpertMassGui
} // namespace MsXpS

==> libxpertmass_1.4.0.orig.tar.gz: libxpertmass-1.4.0/source/XpertMassGui/includes/MsXpS/libXpertMassGui/ScriptingObjectTreeWidgetItem.hpp <==
/* BEGIN software license
 *
 * msXpertSuite - mass spectrometry software suite
 * -----------------------------------------------
 * Copyright(C) 2009,...,2018 Filippo Rusconi
 *
 * http://www.msxpertsuite.org
 *
 * This file is part of the msXpertSuite project.
 *
 * The msXpertSuite project is the successor of the massXpert project. This
 * project now includes various independent modules:
 *
 * - massXpert, model polymer chemistries and simulate mass spectrometric data;
 * - mineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 * END software license
 */


#pragma once


/////////////////////// Qt includes
#include <QTreeWidgetItem>



/////////////////////// libXpertMassCore includes


/////////////////////// libXpertMassGUI includes
#include "MsXpS/libXpertMassGui/ScriptingObjectTreeWidgetItem.hpp"
#include "MsXpS/libXpertMassGui/JavaScriptingWnd.hpp"


/////////////////////// Local includes
#include "MsXpS/export-import-config.h"


namespace MsXpS
{
namespace libXpertMassGui
{

class DECLSPEC ScriptingObjectTreeWidgetItem: public QObject, QTreeWidgetItem
{

  Q_OBJECT
  friend class JavaScriptingWnd;

  public:
  ScriptingObjectTreeWidgetItem(QTreeWidget *parent, int type);
  ScriptingObjectTreeWidgetItem(QTreeWidgetItem *parent, int type);
  ~ScriptingObjectTreeWidgetItem();

  void setQObject(QObject *object);
  void setComment(const QString &comment);
  void setHelp(const QString &help);
  void setColor(const QColor &color);
  void setScriptEntityType(ScriptEntityType type);

  void setProperties(QObject *object        = Q_NULLPTR,
                     const QString &comment = QString(),
                     const QString &help    = QString(),
                     const QColor &color    = Qt::black,
                     ScriptEntityType entityType =
                       ScriptEntityType::UndefinedEntity);

  public slots:

  void setText(int column, const QString &text);

  private:
  QObject *mp_qobject = Q_NULLPTR;
  QString m_comment;
  QString m_help;
  QColor m_color;
  ScriptEntityType m_entityType;
};

} // namespace libXpertMassGui
} // namespace MsXpS
